# Development

## Releasing a new version on PyPI.

Currently I have a GitHub workflow to automatically publish to PyPI when a new
[tagged] release is made on GitHub, so the only step required is to make a new
release.